@@ -1,5 +1,4 @@
 using System;
-using System.Collections;
 using System.Collections.Generic;
 using System.Diagnostics;
 using System.IO;
@@ -789,7 +788,7 @@ namespace Tomboy
 
 		// Reload note data from a complete note XML string
 		// Should referesh note window, too
-		public void LoadForeignNoteXml (string foreignNoteXml)
+		public void LoadForeignNoteXml (string foreignNoteXml, ChangeType changeType)
 		{
 			if (foreignNoteXml == null)
 				throw new ArgumentNullException ("foreignNoteXml");
@@ -852,7 +851,8 @@ namespace Tomboy
 
 			xml.Close ();
 
-			// TODO: Any reason to queue a save here?  Maybe not for sync but for others?
+			// Allow method caller to specify ChangeType (mostly needed by sync)
+			QueueSave (changeType);
 		}
 
 		// TODO: CODE DUPLICATION SUCKS
@@ -1228,7 +1228,7 @@ namespace Tomboy
 		public static string WriteString(NoteData note)
 		{
 			StringWriter str = new StringWriter ();
-			XmlTextWriter xml = new XmlTextWriter (str);
+			XmlWriter xml = XmlWriter.Create (str, XmlEncoder.DocumentSettings);
 			Instance.Write (xml, note);
 			xml.Close ();
 			str.Flush();
@@ -1244,7 +1244,7 @@ namespace Tomboy
 		{
 			string tmp_file = write_file + ".tmp";
 
-			XmlTextWriter xml = new XmlTextWriter (tmp_file, System.Text.Encoding.UTF8);
+			XmlWriter xml = XmlWriter.Create (tmp_file, XmlEncoder.DocumentSettings);
 			Write (xml, note);
 			xml.Close ();
 
@@ -1274,15 +1274,13 @@ namespace Tomboy
 
 		public void WriteFile (TextWriter writer, NoteData note)
 		{
-			XmlTextWriter xml = new XmlTextWriter (writer);
+			XmlWriter xml = XmlWriter.Create (writer, XmlEncoder.DocumentSettings);
 			Write (xml, note);
 			xml.Close ();
 		}
 
-		void Write (XmlTextWriter xml, NoteData note)
+		void Write (XmlWriter xml, NoteData note)
 		{
-			xml.Formatting = Formatting.Indented;
-
 			xml.WriteStartDocument ();
 			xml.WriteStartElement (null, "note", "http://beatniksoftware.com/tomboy");
 			xml.WriteAttributeString(null,
@@ -1409,7 +1407,6 @@ namespace Tomboy
 						switch (xml.Name) {
 						case "title":
 							return xml.ReadString ();
-							break;
 						}
 						break;
 					}
@@ -1429,7 +1426,10 @@ namespace Tomboy
 			if (notes.Count == 1)
 				message = Catalog.GetString ("Really delete this note?");
 			else
-				message = Catalog.GetString ("Really delete these notes?");
+				message = string.Format (Catalog.GetPluralString (
+					"Really delete this {0} note?",
+					"Really delete these {0} notes?",
+					notes.Count), notes.Count);
 			
 			HIGMessageDialog dialog =
 			        new HIGMessageDialog (
